@@ -5,7 +5,8 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
                   qrtol=1e-10,
                   iterlim=150,
                   constraints=NULL,
-                  activePar=rep(TRUE, length(start)),
+                  fixed=NULL,
+                  activePar=NULL,
                   ...) {
    ## Newton-Raphson maximisation
    ## Parameters:
@@ -31,6 +32,7 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
    ## activePar   - an index vector -- which parameters are taken as
    ##               variable (free).  Other paramters are treated as
    ##               fixed constants
+   ## fixed         index vector, which parameters to keep fixed
    ##
    ## RESULTS:
    ## a list of class "maxim":
@@ -56,7 +58,7 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
 
    argNames <- c( "fn", "grad", "hess", "start", "print.level",
       "tol", "reltol", "gradtol", "steptol", "lambdatol", "qrtol",
-      "iterlim", "activePar" )
+      "iterlim", "activePar", "fixed" )
    checkFuncArgs( fn, argNames, "fn", "maxNR" )
    if( !is.null( grad ) ) {
       checkFuncArgs( grad, argNames, "grad", "maxNR" )
@@ -64,7 +66,11 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
    if( !is.null( hess ) ) {
       checkFuncArgs( hess, argNames, "hess", "maxNR" )
    }
-   ##
+
+   ## establish the active parameters.  Internally, we just use 'activePar'
+   fixed <- prepareFixed( start = start, activePar = activePar,
+      fixed = fixed )
+
    if(is.null(constraints)) {
        result <- maxNRCompute(fn=fn, grad=grad, hess=hess,
                               start=start,
@@ -74,14 +80,12 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
                               lambdatol=lambdatol,
                               qrtol=qrtol,
                               iterlim=iterlim,
-                              activePar=activePar,
+                              fixed=fixed,
                               ...)
-    }
-   else {
+   } else {
       if(identical(names(constraints), c("ineqA", "ineqB"))) {
          stop("Inequality constraints not implemented for maxNR")
-      }
-      else if(identical(names(constraints), c("eqA", "eqB"))) {
+      } else if(identical(names(constraints), c("eqA", "eqB"))) {
                            # equality constraints: A %*% beta + B = 0
          result <- sumt(fn=fn, grad=grad, hess=hess,
                         start=start,
@@ -93,10 +97,9 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
                         lambdatol=lambdatol,
                         qrtol=qrtol,
                         iterlim=iterlim,
-                        activePar=activePar,
+                        fixed=fixed,
                         ...) 
-      }
-      else {
+      } else {
          stop("maxBFGS only supports the following constraints:\n",
               "constraints=list(ineqA, ineqB)\n",
               "\tfor A %*% beta + B >= 0 linear inequality constraints\n",
@@ -104,4 +107,5 @@ maxNR <- function(fn, grad=NULL, hess=NULL, start, print.level=0,
               paste(names(constraints), collapse=" "))
       }
    }
+   return( result )
 }
