@@ -5,7 +5,7 @@ maxNRCompute <- function(fn, grad=NULL, hess=NULL,
                   lambdatol=1e-6,
                   qrtol=1e-10,
                   iterlim=150,
-                  activePar=rep(TRUE, nParam),
+                  fixed=NULL,
                   ...) {
    ## Newton-Raphson maximisation
    ## Parameters:
@@ -28,9 +28,8 @@ maxNRCompute <- function(fn, grad=NULL, hess=NULL,
    ## reltol      - maximum allowed reltive difference (stops if < reltol*(abs(fn) + reltol)
    ## gradtol     - maximum allowed norm of gradient vector
    ## iterlim     - maximum # of iterations
-   ## activePar   - an index vector -- which parameters are taken as
-   ##               variable (free).  Other paramters are treated as
-   ##               fixed constants
+   ## fixed       - a logical vector -- which parameters are taken as fixed.
+   ##               Other paramters are treated as variable (free).
    ##
    ## RESULTS:
    ## a list of class "maxim":
@@ -56,7 +55,7 @@ maxNRCompute <- function(fn, grad=NULL, hess=NULL,
 
    argNames <- c( "fn", "grad", "hess", "start", "print.level",
       "tol", "reltol", "gradtol", "steptol", "lambdatol", "qrtol",
-      "iterlim", "activePar" )
+      "iterlim", "activePar", "fixed" )
    checkFuncArgs( fn, argNames, "fn", "maxNR" )
    if( !is.null( grad ) ) {
       checkFuncArgs( grad, argNames, "grad", "maxNR" )
@@ -109,11 +108,10 @@ maxNRCompute <- function(fn, grad=NULL, hess=NULL,
    maxim.type <- "Newton-Raphson maximisation"
    nimed <- names(start)
    nParam <- length(start)
-   if(is.numeric(activePar)) {
-      a <- rep(FALSE, nParam)
-      a[activePar] <- TRUE
-      activePar <- a
-   }
+   ## establish the active parameters.  Internally, we just use 'activePar'
+   activePar <- !fixed
+   rm( fixed )
+
    samm <- NULL
    I <- diag(rep(1, nParam))
                            # I is unit matrix
