@@ -1,10 +1,10 @@
 maximMessage <- function(code) {
    message <- switch(code,
-                     "1" = "gradient close to zero. May be a solution",
-                     "2" = paste("successive function values within tolerance",
-                     "limit.\nMay be a solution"),
+                     "1" = "gradient close to zero",
+                     "2" = "successive function values within tolerance limit",
                      "3" = paste("Last step could not find a value above the",
-                     "current.\nConsider switching to a more robust optimisation method temporarily."),
+                     "current.\nBoundary of parameter space?",
+                     " \nConsider switching to a more robust optimisation method temporarily."),
                      "4" = "Iteration limit exceeded.",
                      "5" = "Infinite value",                        
                      "6" = "Infinite gradient",                        
